<?php declare(strict_types=1);

namespace tildeteam;

use League\CommonMark\Environment\Environment;
use League\CommonMark\Extension\CommonMark\CommonMarkCoreExtension;
use League\CommonMark\Extension\CommonMark\Node\Block\BlockQuote;
use League\CommonMark\Extension\DefaultAttributes\DefaultAttributesExtension;
use League\CommonMark\Extension\HeadingPermalink\HeadingPermalinkExtension;
use League\CommonMark\Extension\TableOfContents\TableOfContentsExtension;
use League\CommonMark\Extension\Table\Table;
use League\CommonMark\Extension\Table\TableExtension;
use League\CommonMark\MarkdownConverter;
use Mni\FrontYAML;

class wiki implements FrontYAML\Markdown\MarkdownParser
{
    private MarkdownConverter $parser;

    public function __construct(bool $bootstrap)
    {
        $config = [
            'heading_permalink' => [
                'id_prefix' => '',
                'fragment_prefix' => '',
                'symbol' => '#',
                'html_class' => 'text-warning',
            ],
            'default_attributes' => [
                Table::class => [
                    'class' => $bootstrap ? ['table', 'table-responsive', 'table-hover', 'table-striped'] : [],
                ],
                BlockQuote::class => [
                    'class' => $bootstrap ? 'blockquote' : '',
                ],
            ],
        ];

        $env = new Environment($config);
        $env->addExtension(new CommonMarkCoreExtension());
        $env->addExtension(new DefaultAttributesExtension());
        $env->addExtension(new HeadingPermalinkExtension());
        $env->addExtension(new TableExtension());
        $env->addExtension(new TableOfContentsExtension());

        $this->parser = new MarkdownConverter($env);
    }

    public function parse(string $markdown): string
    {
        return $this->parser->convert($markdown)->getContent();
    }

    public static function factory(bool $bootstrap = false): FrontYAML\Parser
    {
        return new FrontYAML\Parser(null, new wiki($bootstrap));
    }
}
